@@ -3,7 +3,7 @@ package Class::Usul::Schema;
 use namespace::autoclean;
 
 use Moo;
-use Class::Usul::Constants   qw( COMMA FAILED FALSE NUL OK SPC TRUE );
+use Class::Usul::Constants   qw( AS_PARA COMMA FAILED FALSE NUL OK SPC TRUE );
 use Class::Usul::Crypt::Util qw( encrypt_for_config );
 use Class::Usul::Functions   qw( distname ensure_class_loaded io throw );
 use Class::Usul::Options;
@@ -16,9 +16,10 @@ with    q(Class::Usul::TraitFor::ConnectInfo);
 # Public attributes
 option 'attrs'          => is => 'ro',   isa => HashRef,
    documentation        => 'Default database connection attributes',
-   default              => sub { { add_drop_table => TRUE,
-                                   no_comments    => TRUE, } },
-   format               => 's%',   init_arg       => 'dbattrs';
+   default              => sub { { add_drop_table    => TRUE,
+                                   no_comments       => TRUE,
+                                   quote_identifiers => TRUE, } },
+   format               => 's%',   init_arg          => 'dbattrs';
 
 option 'database'       => is => 'ro',   isa => NonEmptySimpleStr,
    documentation        => 'The database to connect to',
@@ -57,9 +58,6 @@ has 'connect_info'      => is => 'lazy', isa => ArrayRef, builder => sub {
    $_[ 0 ]->get_connect_info( $_[ 0 ], { database => $_[ 0 ]->database } ) },
    init_arg             => undef;
 
-has 'paragraph'         => is => 'ro',   isa => HashRef,
-   default              => sub { { cl => TRUE, fill => TRUE, nl => TRUE } };
-
 # Public methods
 sub create_database : method {
    my $self = shift; my $ddl;
@@ -113,7 +111,7 @@ sub create_schema : method { # Create databases and edit credentials
       $text   .= 'For Postgres the driver is Pg and the port 5432';
    my $default = $self->yes;
 
-   $self->output( $text, $self->paragraph );
+   $self->output( $text, AS_PARA );
    $self->yorn( 'Create database schema', $default, TRUE, 0 ) or return OK;
    # Edit the config file that contains the database connection info
    $self->edit_credentials;
@@ -320,7 +318,7 @@ sub _get_db_admin_creds {
    my $text   = 'Need the database administrators id and password to perform ';
       $text  .= "a ${reason} operation";
 
-   $self->output( $text, $self->paragraph );
+   $self->output( $text, AS_PARA );
 
    my $prompt = 'Database administrator id';
    my $user   = $self->db_admin_ids->{ lc $self->driver } || NUL;
@@ -524,7 +522,7 @@ Patches are welcome
 
 =head1 Author
 
-Peter Flanigan, C<< <Support at RoxSoft.co.uk> >>
+Peter Flanigan, C<< <pjfl@cpan.org> >>
 
 =head1 License and Copyright
 
